import requests
import streamlit as st
bmac_api = st.secrets["bmac_api_key"]

def extract_payer_emails(json_response):
    payer_emails = []

    for item in json_response['data']:
        payer_email = item['payer_email']
        payer_emails.append(payer_email)

    return payer_emails

def get_bmac_payers(access_token=bmac_api, one_time=False):
    if one_time == False:
        url = "https://developers.buymeacoffee.com/api/v1/subscriptions?status=active"
        headers = {"Authorization": f"Bearer {access_token}"}
        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            return extract_payer_emails(response.json())
        else:
            raise Exception(f"Error fetching active subscriptions: {response.status_code} - {response.text}")
    else:
        url = "https://developers.buymeacoffee.com/api/v1/supporters"
        headers = {"Authorization": f"Bearer {access_token}"}
        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            return extract_payer_emails(response.json())
        else:
            raise Exception(f"Error fetching active subscriptions: {response.status_code} - {response.text}")


import streamlit as st
from .google_auth import get_logged_in_user_email, show_login_button
from .stripe_auth import get_customer_emails, redirect_button
from .buymeacoffee_auth import get_bmac_payers

payment_provider = st.secrets.get("payment_provider", "stripe")

def add_auth(required=True):
    if required:
        require_auth()
    else:
        optional_auth()

def require_auth():
    user_email = get_logged_in_user_email()

    if not user_email:
        show_login_button()
        st.stop()
    if payment_provider == "stripe":
        customer_emails = get_customer_emails()
    elif payment_provider == "bmac":
        customer_emails = get_bmac_payers()

    if user_email not in customer_emails:
        redirect_button(text="Subscribe now!",
                        customer_email=user_email,
                        payment_provider=payment_provider)
        st.session_state.user_subscribed = False
        st.stop()
    elif user_email in customer_emails:
        st.session_state.user_subscribed = True

    if st.sidebar.button("Logout", type="primary"):
        del st.session_state.email
        del st.session_state.user_subscribed
        st.experimental_rerun()

def optional_auth():
    user_email = get_logged_in_user_email()
    if payment_provider == "stripe":
        customer_emails = get_customer_emails()
    elif payment_provider == "bmac":
        customer_emails = get_bmac_payers()

    if not user_email:
        show_login_button()
        st.session_state.email = ""
        st.sidebar.markdown("")

    if user_email and user_email not in customer_emails:
        redirect_button(text="Subscribe now!", customer_email="", payment_provider=payment_provider)
        st.sidebar.markdown("")
        st.session_state.user_subscribed = False

    elif user_email in customer_emails:
        st.session_state.user_subscribed = True

    if st.session_state.email != "":
        if st.sidebar.button("Logout", type="primary"):
            del st.session_state.email
            del st.session_state.user_subscribed
            st.experimental_rerun()


import streamlit as st
import stripe
import urllib.parse

testing_mode = st.secrets.get("testing_mode", False)
stripe.api_key = st.secrets["stripe_api_key_test"] if testing_mode else st.secrets["stripe_api_key"]
stripe_link = st.secrets["stripe_link_test"] if testing_mode else st.secrets["stripe_link"]


def redirect_button(
    text: str,
    customer_email: str,
    color="#FD504D",
    payment_provider: str = "stripe",
):
    encoded_email = urllib.parse.quote(customer_email)
    if payment_provider == "stripe":
        button_url = f"{stripe_link}?prefilled_email={encoded_email}"
    elif payment_provider == "bmac":
        button_url = f"{st.secrets['bmac_link']}"

    st.sidebar.markdown(
        f"""
    <a href="{button_url}" target="_blank">
        <div style="
            display: inline-block;
            padding: 0.5em 1em;
            color: #FFFFFF;
            background-color: {color};
            border-radius: 3px;
            text-decoration: none;">
            {text}
        </div>
    </a>
    """,
        unsafe_allow_html=True,
    )


def get_customer_emails():
    customers = stripe.Customer.list()
    emails = []
    for i in customers["data"]:
        emails.append(i["email"])
    return emails
